# Alasco

## Introduction  

This package is SDK for `python` to facilitate interaction with the Alasco API.

The official documentation from [Alasco](https://www.alasco.com/) can be found [here](https://developer.alasco.de/).

## How to install it

```bash
pip install alasco
```

## Dependancies 

It uses `pandas` and `requests` under the hood to facilitate the data manipulation.
